{% extends "admin/change_list.html" %} {% load i18n admin_urls %} {% block breadcrumbs %}
{% trans 'Home' %} › {{ history_model_opts.app_config.verbose_name }} › {{ history_model_opts.verbose_name_plural|capfirst }} {% if history_object %} › {{ history_object|truncatewords:"18" }} {% else %} {% endif %} › {% trans 'History' %}
{% endblock %} {% block content_title %}

# {% trans 'History' %}

{% endblock %}